# Compiles pygame on homebrew for distribution.
# This may not be what you want to do if not on travisci.

set -e

# Work around https://github.com/travis-ci/travis-ci/issues/8703 :-@
# Travis overrides cd to do something with Ruby. Revert to the default.
unset -f cd
shell_session_update() { :; }


set UPDATE_UNBOTTLED='0'


echo -en 'travis_fold:start:brew.update\\r'
echo "Updating Homebrew listings..."
brew update
echo -en 'travis_fold:end:brew.update\\r'
export HOMEBREW_NO_AUTO_UPDATE=1

brew install ccache
export PATH="/usr/local/opt/ccache/libexec:$PATH"

brew uninstall openssl --ignore-dependencies
brew uninstall readline --ignore-dependencies

brew uninstall --force --ignore-dependencies pkg-config
brew install pkg-config

if [[ ${BUILD_UNIVERSAL} == "1" ]]; then
  UNIVERSAL_FLAG='--universal'
  echo "Using --universal option for builds"
else
  UNIVERSAL_FLAG=''
  echo "Not using --universal option for builds"
fi

# Only compile from source if doing a release. on tag or master.
# This saves compile times for normal PR testing.
echo "About to install dependencies"
echo $TRAVIS_TAG
echo $TRAVIS_BRANCH
echo $TRAVIS_PULL_REQUEST
if [ "$TRAVIS_PULL_REQUEST" = "false" ] && ([ -n "$TRAVIS_TAG" ] || [ "$TRAVIS_BRANCH" = "master" ]); then
	echo "building more things from source"

	# brew uninstall --force --ignore-dependencies sdl
	# brew uninstall --force --ignore-dependencies sdl_image
	# brew uninstall --force --ignore-dependencies sdl_mixer
	# brew uninstall --force --ignore-dependencies sdl_ttf
	# brew uninstall --force --ignore-dependencies smpeg
	brew uninstall --force --ignore-dependencies sdl2
	brew uninstall --force --ignore-dependencies sdl2_image
	brew uninstall --force --ignore-dependencies sdl2_mixer
	brew uninstall --force --ignore-dependencies sdl2_ttf
	#brew uninstall --force --ignore-dependencies smpeg2

	brew uninstall --force --ignore-dependencies jpeg
	brew uninstall --force --ignore-dependencies libpng
	brew uninstall --force --ignore-dependencies libtiff
	brew uninstall --force --ignore-dependencies webp
	brew uninstall --force --ignore-dependencies flac
	brew uninstall --force --ignore-dependencies fluid-synth
	brew uninstall --force --ignore-dependencies libmikmod
	brew uninstall --force --ignore-dependencies libvorbis
	brew uninstall --force --ignore-dependencies portmidi
	brew uninstall --force --ignore-dependencies freetype
fi


source "buildconfig/ci/travis/.travis_osx_utils.sh"

function clear_package_cache {
  rm -f "$HOME/HomebrewLocal/json/$1--*"
  if [[ -e "$HOME/HomebrewLocal/path/$1" ]]; then
    echo "Removing cached $1."
    rm -f $(< "$HOME/HomebrewLocal/path/$1") && rm -f "$HOME/HomebrewLocal/path/$1"
  fi
}

function check_local_bottles {
  echo "Checking local bottles in $HOME/HomebrewLocal/json/..."
  for jsonfile in $HOME/HomebrewLocal/json/*.json; do
    [ -e "$jsonfile" ] || continue
    local pkg="$(sed 's/\(.*\)--.*/\1/' <<<"$(basename $jsonfile)")"
    echo "Package: $pkg. JSON: $jsonfile."

    local filefull=$(< "$HOME/HomebrewLocal/path/$pkg")
    local file=$(basename $filefull)
    echo "$pkg: local bottle path: $filefull"

    echo "Adding local bottle into $pkg's formula."
    brew bottle --merge --write "$jsonfile" || true
  done
  echo "Done checking local bottles."
}

if [ "${1}" == "--no-installs" ]; then
  unset HOMEBREW_BUILD_BOTTLE
  unset HOMEBREW_BOTTLE_ARCH
  return 0
fi

set +e

TAP_SOURCE="pygame/portmidi/"
brew tap "pygame/portmidi"

check_local_bottles

# install_or_upgrade sdl ${UNIVERSAL_FLAG}
install_or_upgrade jpeg ${UNIVERSAL_FLAG}
UPDATE_UNBOTTLED='1' install_or_upgrade libpng ${UNIVERSAL_FLAG}
UPDATE_UNBOTTLED='1' install_or_upgrade "${TAP_SOURCE}xz" ${UNIVERSAL_FLAG}
UPDATE_UNBOTTLED='1' install_or_upgrade libtiff ${UNIVERSAL_FLAG}
install_or_upgrade webp ${UNIVERSAL_FLAG}
install_or_upgrade "${TAP_SOURCE}libogg" ${UNIVERSAL_FLAG}
install_or_upgrade "${TAP_SOURCE}libvorbis" ${UNIVERSAL_FLAG}
install_or_upgrade "${TAP_SOURCE}flac" ${UNIVERSAL_FLAG}
install_or_upgrade "${TAP_SOURCE}fluid-synth"
install_or_upgrade "${TAP_SOURCE}libmikmod" ${UNIVERSAL_FLAG}
# install_or_upgrade "${TAP_SOURCE}smpeg"
# install_or_upgrade "${TAP_SOURCE}smpeg2"


# Because portmidi hates us... and installs python2, which messes homebrew up.
# So we install portmidi from our own formula.
install_or_upgrade "${TAP_SOURCE}portmidi" ${UNIVERSAL_FLAG}

install_or_upgrade freetype ${UNIVERSAL_FLAG}
# install_or_upgrade sdl_ttf ${UNIVERSAL_FLAG}
# install_or_upgrade sdl_image ${UNIVERSAL_FLAG}
# install_or_upgrade sdl_mixer ${UNIVERSAL_FLAG} --with-flac --with-fluid-synth --with-smpeg


install_or_upgrade "${TAP_SOURCE}sdl2"
install_or_upgrade sdl2_gfx
install_or_upgrade sdl2_image
install_or_upgrade "${TAP_SOURCE}sdl2_mixer"
install_or_upgrade sdl2_ttf

set -e

unset HOMEBREW_BUILD_BOTTLE
unset HOMEBREW_BOTTLE_ARCH


echo "finished buildconfig/ci/travis/.travis_osx_before_install.sh"
